==> style-react-1.1.23.tgz: package/esm/ThemeProvider/Theme.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
const _excluded = ["root", "value", "addCssVariables", "children"];
import React from 'react';
import is from '@amaui/utils/is';
import merge from '@amaui/utils/merge';
import hash from '@amaui/utils/hash';
import isEnvironment from '@amaui/utils/isEnvironment';
import { AmauiTheme, classNames } from '@amaui/style';
import ThemeContext from './Context';
import useAmauiTheme from './useAmauiTheme';
const resolveValue = value => {
  const toFilterOut = ['id', 'element', 'subscriptions'];
  const valueNew = {};
  Object.keys(value).filter(item => toFilterOut.indexOf(item) === -1).forEach(item => valueNew[item] = value[item]);
  return valueNew;
};
const hashValue = value => {
  const allowed = ['preference', 'mode', 'palette', 'shape', 'breakpoints', 'space', 'shadows', 'typography', 'transitions', 'z_index', 'ui'];
  const valueNew = {};
  Object.keys(value).filter(item => allowed.includes(item)).forEach(item => valueNew[item] = value[item]);
  return hash(valueNew);
};
const Theme = /*#__PURE__*/React.forwardRef((props, ref) => {
  const [init, setInit] = React.useState(false);
  const {
      root = false,
      value: valueLocal = {},
      addCssVariables = true,
      children
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const refs = {
    root: React.useRef(),
    init: React.useRef(),
    id: React.useId(),
    styleSheet: React.useRef()
  };
  refs.init.current = init;
  const valueParent = useAmauiTheme() || {};
  const [value, setValue] = React.useState(() => new AmauiTheme(merge(resolveValue(is('function', valueLocal) ? valueLocal(valueParent) : valueLocal), resolveValue(valueParent), {
    copy: true
  })));
  const addCssVariablesMethod = React.useCallback(() => {
    if (!refs.styleSheet.current) {
      refs.styleSheet.current = window.document.createElement('style');
      refs.styleSheet.current.setAttribute('data-amaui', 'true');
      refs.styleSheet.current.setAttribute('data-version', 'static');
      refs.styleSheet.current.setAttribute('data-name', 'vars');
      window.document.head.append(refs.styleSheet.current);
    }
    const values = [];
    const prefix = 'amaui';

    // Palette
    // Color
    Object.keys(value.palette.color).forEach(item => {
      Object.keys(value.palette.color[item]).forEach(itemValue => {
        values.push(`--${prefix}-palette-color-${item}-${itemValue}: ${value.palette.color[item][itemValue]}`);
      });
    });

    // Text
    Object.keys(value.palette.text).filter(item => !['active', 'divider', 'disabled', 'hover', 'focus', 'selected'].includes(item)).forEach(item => {
      Object.keys(value.palette.text[item]).forEach(itemValue => {
        values.push(`--${prefix}-palette-text-${item}-${itemValue}: ${value.palette.text[item][itemValue]}`);
      });
    });
    Object.keys(value.palette.text).filter(item => ['active', 'divider', 'disabled', 'hover', 'focus', 'selected'].includes(item)).forEach(item => {
      values.push(`--${prefix}-palette-text-${item}: ${value.palette.text[item]}`);
    });

    // Background
    Object.keys(value.palette.background).forEach(item => {
      Object.keys(value.palette.background[item]).forEach(itemValue => {
        values.push(`--${prefix}-palette-background-${item}-${itemValue}: ${value.palette.background[item][itemValue]}`);
      });
    });

    // Visual contrast
    Object.keys(value.palette.visual_contrast).forEach(item => {
      Object.keys(value.palette.visual_contrast[item].opacity).forEach(itemValue => {
        values.push(`--${prefix}-palette-visual-contrast-${item}-opacity-${itemValue}: ${value.palette.visual_contrast[item].opacity[itemValue]}`);
      });
    });

    // Shape
    values.push(`--${prefix}-shape-radius-unit: ${value.shape.radius.unit}`);
    Object.keys(value.shape.radius.values).forEach(item => {
      values.push(`--${prefix}-shape-radius-values-${item}: ${value.shape.radius.values[item]}`);
    });

    // Space
    values.push(`--${prefix}-space-unit: ${value.space.unit}`);
    Object.keys(value.space.values).forEach(item => {
      values.push(`--${prefix}-space-values-${item}: ${value.space.values[item]}`);
    });

    // Shadows
    Object.keys(value.shadows.values).forEach(item => {
      Object.keys(value.shadows.values[item]).forEach(itemValue => {
        values.push(`--${prefix}-shadows-${item}-${itemValue}: ${value.shadows.values[item][itemValue]}`);
      });
    });

    // Typography
    Object.keys(value.typography.font_family).forEach(item => values.push(`--${prefix}-typography-font-family-${item}: ${value.typography.font_family[item]}`));
    values.push(`--${prefix}-typography-font-size-html: ${value.typography.font_size.html}`);
    values.push(`--${prefix}-typography-unit: ${value.typography.unit}`);

    // Transitions
    Object.keys(value.transitions.duration).forEach(item => values.push(`--${prefix}-transitions-duration-${item}: ${value.transitions.duration[item]}`));
    Object.keys(value.transitions.timing_function).forEach(item => values.push(`--${prefix}-transitions-timing-function-${item}: ${value.transitions.timing_function[item]}`));

    // zIndex
    Object.keys(value.z_index).forEach(item => values.push(`--${prefix}-z-index-${item}: ${value.z_index[item]}`));

    // Add to styleSheet innerHTML
    refs.styleSheet.current.innerHTML = `
${refs.root.current ? `#${refs.id}` : ':root'} {
${values.map(item => `\t${item};`).join('\n')}
}
`;
  }, [value]);
  React.useEffect(() => {
    if (refs.root.current) {
      const amauiTheme = new AmauiTheme(value, {
        element: refs.root.current
      });
      amauiTheme.id = value.id;
      amauiTheme.subscriptions = value.subscriptions;

      // Init
      setValue(amauiTheme);
    }
    setInit(true);
  }, []);
  React.useEffect(() => {
    addCssVariablesMethod();
  }, [refs.root.current, valueParent, value]);
  React.useEffect(() => {
    if (init) {
      value.update(merge(resolveValue(is('function', valueLocal) ? valueLocal(valueParent) : valueLocal), resolveValue(valueParent), {
        copy: true
      }));
      const amauiTheme = new AmauiTheme(value, {
        element: refs.root?.current
      });
      amauiTheme.id = value.id;
      amauiTheme.subscriptions = value.subscriptions;
      setValue(amauiTheme);
    }
  }, [hashValue(resolveValue(valueLocal)), valueParent?.palette?.light]);
  const update = updateValue => {
    if (updateValue !== undefined) {
      // Update
      value.update(updateValue);
      const amauiTheme = new AmauiTheme(value, {
        element: refs.root?.current || isEnvironment('browser') && window.document.body
      });
      amauiTheme.id = value.id;
      amauiTheme.subscriptions = value.subscriptions;

      // Init
      setValue(amauiTheme);
      return value;
    }
  };

  // Update method
  value.updateWithRerender = update;
  if (root) {
    return /*#__PURE__*/React.createElement(ThemeContext.Provider, {
      value: value
    }, /*#__PURE__*/React.createElement("div", _extends({
      ref: item => {
        refs.root.current = item;
        if (ref?.current) ref.current = item;
      }
    }, other, {
      id: refs.id,
      className: classNames(other?.className)
    }), children));
  }
  return /*#__PURE__*/React.createElement(ThemeContext.Provider, {
    value: value
  }, children);
});
export default Theme;

==> style-react-1.1.29.tgz: package/esm/ThemeProvider/Theme.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
const _excluded = ["root", "value", "addCssVariables", "children"];
import React from 'react';
import is from '@amaui/utils/is';
import merge from '@amaui/utils/merge';
import hash from '@amaui/utils/hash';
import isEnvironment from '@amaui/utils/isEnvironment';
import { AmauiTheme, classNames } from '@amaui/style';
import ThemeContext from './Context';
import useAmauiTheme from './useAmauiTheme';
const hashValue = value => {
  const allowed = ['direction', 'preference', 'mode', 'palette', 'shape', 'breakpoints', 'space', 'shadows', 'typography', 'transitions', 'z_index'];
  const valueNew = {};
  Object.keys(value).filter(item => allowed.includes(item)).forEach(item => valueNew[item] = value[item]);
  return hash(valueNew);
};
const resolveValue = value => {
  const notAllowed = ['subscriptions', 'id', 'element', 'updateWithRerender'];
  const valueNew = {};
  Object.keys(value).filter(item => !notAllowed.includes(item)).forEach(item => valueNew[item] = value[item]);
  return valueNew;
};
const Theme = /*#__PURE__*/React.forwardRef((props, ref) => {
  const [init, setInit] = React.useState(false);
  const {
      root = false,
      value: valueLocal = {},
      addCssVariables = true,
      children
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const refs = {
    root: React.useRef(),
    init: React.useRef(),
    id: React.useId(),
    styleSheet: React.useRef()
  };
  refs.init.current = init;
  const valueParent = useAmauiTheme() || {};
  const [value, setValue] = React.useState(() => new AmauiTheme(merge(resolveValue(is('function', valueLocal) ? valueLocal(valueParent) : valueLocal), resolveValue(valueParent), {
    copy: true
  })));
  const addCssVariablesMethod = React.useCallback(() => {
    if (!refs.styleSheet.current) {
      refs.styleSheet.current = window.document.createElement('style');
      refs.styleSheet.current.setAttribute('data-amaui', 'true');
      refs.styleSheet.current.setAttribute('data-version', 'static');
      refs.styleSheet.current.setAttribute('data-name', 'vars');
      window.document.head.append(refs.styleSheet.current);
    }
    const values = [];
    const prefix = 'amaui';

    // Palette
    // Color
    Object.keys(value.palette.color).forEach(item => {
      Object.keys(value.palette.color[item]).forEach(itemValue => {
        values.push(`--${prefix}-palette-color-${item}-${itemValue}: ${value.palette.color[item][itemValue]}`);
      });
    });

    // Text
    Object.keys(value.palette.text).filter(item => !['active', 'divider', 'disabled', 'hover', 'focus', 'selected'].includes(item)).forEach(item => {
      Object.keys(value.palette.text[item]).forEach(itemValue => {
        values.push(`--${prefix}-palette-text-${item}-${itemValue}: ${value.palette.text[item][itemValue]}`);
      });
    });
    Object.keys(value.palette.text).filter(item => ['active', 'divider', 'disabled', 'hover', 'focus', 'selected'].includes(item)).forEach(item => {
      values.push(`--${prefix}-palette-text-${item}: ${value.palette.text[item]}`);
    });

    // Background
    Object.keys(value.palette.background).forEach(item => {
      Object.keys(value.palette.background[item]).forEach(itemValue => {
        values.push(`--${prefix}-palette-background-${item}-${itemValue}: ${value.palette.background[item][itemValue]}`);
      });
    });

    // Visual contrast
    Object.keys(value.palette.visual_contrast).forEach(item => {
      Object.keys(value.palette.visual_contrast[item].opacity).forEach(itemValue => {
        values.push(`--${prefix}-palette-visual-contrast-${item}-opacity-${itemValue}: ${value.palette.visual_contrast[item].opacity[itemValue]}`);
      });
    });

    // Shape
    values.push(`--${prefix}-shape-radius-unit: ${value.shape.radius.unit}`);
    Object.keys(value.shape.radius.values).forEach(item => {
      values.push(`--${prefix}-shape-radius-values-${item}: ${value.shape.radius.values[item]}`);
    });

    // Space
    values.push(`--${prefix}-space-unit: ${value.space.unit}`);
    Object.keys(value.space.values).forEach(item => {
      values.push(`--${prefix}-space-values-${item}: ${value.space.values[item]}`);
    });

    // Shadows
    Object.keys(value.shadows.values).forEach(item => {
      Object.keys(value.shadows.values[item]).forEach(itemValue => {
        values.push(`--${prefix}-shadows-${item}-${itemValue}: ${value.shadows.values[item][itemValue]}`);
      });
    });

    // Typography
    Object.keys(value.typography.font_family).forEach(item => values.push(`--${prefix}-typography-font-family-${item}: ${value.typography.font_family[item]}`));
    values.push(`--${prefix}-typography-font-size-html: ${value.typography.font_size.html}`);
    values.push(`--${prefix}-typography-unit: ${value.typography.unit}`);

    // Transitions
    Object.keys(value.transitions.duration).forEach(item => values.push(`--${prefix}-transitions-duration-${item}: ${value.transitions.duration[item]}`));
    Object.keys(value.transitions.timing_function).forEach(item => values.push(`--${prefix}-transitions-timing-function-${item}: ${value.transitions.timing_function[item]}`));

    // zIndex
    Object.keys(value.z_index).forEach(item => values.push(`--${prefix}-z-index-${item}: ${value.z_index[item]}`));

    // Add to styleSheet innerHTML
    refs.styleSheet.current.innerHTML = `
${refs.root.current ? `#${refs.id}` : ':root'} {
${values.map(item => `\t${item};`).join('\n')}
}
`;
  }, [value]);
  React.useEffect(() => {
    if (refs.root.current) {
      const amauiTheme = new AmauiTheme(value, {
        element: refs.root.current
      });
      amauiTheme.id = value.id;
      amauiTheme.subscriptions = value.subscriptions;

      // Init
      setValue(amauiTheme);
    }
    setInit(true);
  }, []);
  React.useEffect(() => {
    addCssVariablesMethod();
  }, [refs.root.current, valueParent, value]);
  React.useEffect(() => {
    if (init) {
      value.update(merge(resolveValue(is('function', valueLocal) ? valueLocal(valueParent) : valueLocal), resolveValue(valueParent), {
        copy: true
      }));
      const amauiTheme = new AmauiTheme(value, {
        element: refs.root?.current
      });
      amauiTheme.id = value.id;
      amauiTheme.subscriptions = value.subscriptions;
      setValue(amauiTheme);
    }
  }, [hashValue(valueLocal), valueParent?.palette?.light]);
  const update = updateValue => {
    if (updateValue !== undefined) {
      // Update
      value.update(updateValue);
      const amauiTheme = new AmauiTheme(value, {
        element: refs.root?.current || isEnvironment('browser') && window.document.body
      });
      amauiTheme.id = value.id;
      amauiTheme.subscriptions = value.subscriptions;

      // Init
      setValue(amauiTheme);
      return value;
    }
  };

  // Update method
  value.updateWithRerender = update;
  if (root) {
    return /*#__PURE__*/React.createElement(ThemeContext.Provider, {
      value: value
    }, /*#__PURE__*/React.createElement("div", _extends({
      ref: item => {
        refs.root.current = item;
        if (ref?.current) ref.current = item;
      }
    }, other, {
      id: refs.id,
      className: classNames(other?.className)
    }), children));
  }
  return /*#__PURE__*/React.createElement(ThemeContext.Provider, {
    value: value
  }, children);
});
export default Theme;
